@@ -30,11 +30,11 @@ Log::AutoDump - Log with automatic dumping of references and objects.
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =cut
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 $VERSION = eval $VERSION;
 
@@ -256,6 +256,21 @@ sub _fh
 	return $self->{ _fh };
 }
 
+=head3 abort
+
+Close the log filehandle.
+
+ $log->abort;
+
+=cut
+
+sub abort
+{
+    my $self = shift;
+    $self->_fh->close;
+    return $self;
+}
+
 =head3 msg
 
  $log->msg(2, "Hello");
@@ -552,8 +567,6 @@ sub is_fatal
 }
 
 
-
-
 =head1 TODO
 
 simple scripts (the caller stack)
